@@ -1,20 +1,17 @@
-import datetime
-
 import pytest
 
-from tests import mock, requires_crt
+import botocore
+from tests import FreezeTime, requires_crt
 from tests.unit.auth.test_sigv4 import (
     DATE,
-    SERVICE,
     REGION,
+    SERVICE,
     SignatureTestCase,
     assert_equal,
     create_request_from_raw_request,
     generate_test_cases,
 )
 
-import botocore
-
 
 def _test_crt_signature_version_4(test_case):
     test_case = SignatureTestCase(test_case)
@@ -36,13 +33,6 @@ def _test_crt_signature_version_4(test_case):
 
 @requires_crt()
 @pytest.mark.parametrize("test_case", generate_test_cases())
+@FreezeTime(module=botocore.auth.datetime, date=DATE)
 def test_signature_version_4(test_case):
-    datetime_patcher = mock.patch.object(
-        botocore.auth.datetime, "datetime", mock.Mock(wraps=datetime.datetime)
-    )
-    mocked_datetime = datetime_patcher.start()
-    mocked_datetime.utcnow.return_value = DATE
-
     _test_crt_signature_version_4(test_case)
-
-    datetime_patcher.stop()
