@@ -19,17 +19,18 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 # IN THE SOFTWARE.
 
-import os
 import contextlib
 import copy
+import os
 
 from botocore.exceptions import DataNotFoundError, UnknownServiceError
-from botocore.loaders import JSONFileLoader
-from botocore.loaders import Loader, create_loader
-from botocore.loaders import ExtrasProcessor
-
-from tests import mock
-from tests import BaseEnvVar
+from botocore.loaders import (
+    ExtrasProcessor,
+    JSONFileLoader,
+    Loader,
+    create_loader,
+)
+from tests import BaseEnvVar, mock
 
 
 class TestJSONFileLoader(BaseEnvVar):
